@@ -4,8 +4,9 @@ from pycomposefile.service.service_blkio_config import BlkioConfig
 from pycomposefile.service.service_deploy import Deploy
 from pycomposefile.service.service_credential_spec import CredentialSpec
 from pycomposefile.service.service_cap import Cap
-from pycomposefile.service.service_configs import Configs
+from pycomposefile.service.service_configs import Configs, Secrets
 from pycomposefile.service.service_command import Command
+from pycomposefile.service.service_environment import Environment, EnvFile
 from pycomposefile.service.service_ports import Ports
 from pycomposefile.compose_element import ComposeElement, ComposeStringOrListElement, ComposeByteValue
 
@@ -87,7 +88,10 @@ class Service(ComposeElement):
         "configs": (Configs,
                     "https://github.com/compose-spec/compose-spec/blob/master/spec.md#configs"),
         "depends_on": (DependsOn, "https://github.com/compose-spec/compose-spec/blob/master/spec.md#depends_on"),
+        "env_file": (EnvFile, "https://github.com/compose-spec/compose-spec/blob/master/spec.md#env_file"),
+        "environment": (Environment, "https://github.com/compose-spec/compose-spec/blob/master/spec.md#environment"),
         "mem_reservation": (ComposeByteValue, "https://github.com/compose-spec/compose-spec/blob/master/spec.md#mem_reservation"),
+        "secrets": (Secrets, "https://github.com/compose-spec/compose-spec/blob/master/spec.md#secrets")
     }
 
     def entrypoint_and_command(self):
@@ -101,3 +105,11 @@ class Service(ComposeElement):
             if self.command is not None:
                 container_entrypoint_and_command += self.command.command_string()
             return container_entrypoint_and_command
+
+    def resolve_environment_hierarchy(self):
+        if self.env_file is not None:
+            env_file = self.env_file.readFile()
+            env_file.update(self.environment)
+            return env_file
+        else:
+            return self.environment
